pub struct PathCounts { /* private fields */ }Implementations
Sourceimpl PathCounts
impl PathCounts
pub fn empty_indexed(name: &str) -> Self
pub fn empty_mapped(name: &str) -> Self
pub fn new(len: usize, name: &str) -> Self
pub fn len(&self) -> usize
pub fn increment_path_count_for_node(&mut self, node: NodeId, val: usize)
pub fn increment_path_count_for_node_from( &mut self, node: NodeId, other: NodeId, )
pub fn update_path_counts(&mut self, dst: NodeId, src: NodeId)
pub fn set_path_count_for_node(&mut self, node: NodeId, count: usize)
pub fn path_count_ratio(&self, v_p: NodeId, v_n: NodeId) -> f64
Sourcepub fn set_path_count_to_one(&mut self, source: NodeId)
pub fn set_path_count_to_one(&mut self, source: NodeId)
Convenience method for the common case of setting the path count to one
Sourcepub fn set_path_count_to_zero(&mut self, source: NodeId)
pub fn set_path_count_to_zero(&mut self, source: NodeId)
Convenience method for the common case of zeroing the path count
pub fn reinit(&mut self, len: usize)